@@ -51,6 +51,9 @@ project.delete()
 fork = gl.project_forks.create({}, project_id=1)
 # or
 fork = project.forks.create({})
+
+# fork to a specific namespace
+fork = gl.project_forks.create({'namespace': 'myteam'}, project_id=1)
 # end fork
 
 # forkrelation
@@ -223,11 +226,11 @@ f = project.files.create({'file_path': 'testfile',
 
 # files update
 f.content = 'new content'
-f.save(branch='master', commit_message='Update testfile')
+f.save(branch_name='master', commit_message='Update testfile')
 
 # or for binary data
 f.content = base64.b64encode(open('image.png').read())
-f.save(branch='master', commit_message='Update testfile', encoding='base64')
+f.save(branch_name='master', commit_message='Update testfile', encoding='base64')
 # end files update
 
 # files delete
