@@ -95,6 +95,14 @@ class GitlabBuildRetryError(GitlabRetryError):
     pass
 
 
+class GitlabBuildPlayError(GitlabRetryError):
+    pass
+
+
+class GitlabBuildEraseError(GitlabRetryError):
+    pass
+
+
 class GitlabPipelineRetryError(GitlabRetryError):
     pass
 
