@@ -689,7 +689,7 @@ class ApplicationSettings(GitlabObject):
                            'domain_blacklist',
                            'domain_blacklist_enabled',
                            'domain_whitelist',
-                           'enabled_git_access_protocol'
+                           'enabled_git_access_protocol',
                            'gravatar_enabled',
                            'home_page_url',
                            'max_attachment_size',
@@ -961,6 +961,18 @@ class ProjectBuild(GitlabObject):
         r = self.gitlab._raw_post(url)
         raise_error_from_response(r, GitlabBuildRetryError, 201)
 
+    def play(self, **kwargs):
+        """Trigger a build explicitly."""
+        url = '/projects/%s/builds/%s/play' % (self.project_id, self.id)
+        r = self.gitlab._raw_post(url)
+        raise_error_from_response(r, GitlabBuildPlayError, 201)
+
+    def erase(self, **kwargs):
+        """Erase the build (remove build artifacts and trace)."""
+        url = '/projects/%s/builds/%s/erase' % (self.project_id, self.id)
+        r = self.gitlab._raw_post(url)
+        raise_error_from_response(r, GitlabBuildEraseError, 201)
+
     def keep_artifacts(self, **kwargs):
         """Prevent artifacts from being delete when expiration is set.
 
@@ -1169,6 +1181,7 @@ class ProjectFork(GitlabObject):
     canList = False
     canGet = False
     requiredUrlAttrs = ['project_id']
+    optionalCreateAttrs = ['namespace']
 
 
 class ProjectForkManager(BaseManager):
@@ -1378,8 +1391,7 @@ class ProjectMergeRequestNoteManager(BaseManager):
 
 
 class ProjectMergeRequest(GitlabObject):
-    _url = '/projects/%(project_id)s/merge_request'
-    _urlPlural = '/projects/%(project_id)s/merge_requests'
+    _url = '/projects/%(project_id)s/merge_requests'
     _constructorTypes = {'author': 'User', 'assignee': 'User'}
     requiredUrlAttrs = ['project_id']
     requiredCreateAttrs = ['source_branch', 'target_branch', 'title']
@@ -1787,7 +1799,7 @@ class ProjectService(GitlabObject):
         'irker': (('recipients', ), ('default_irc_uri', 'server_port',
                                      'server_host', 'colorize_messages')),
         'jira': (('new_issue_url', 'project_url', 'issues_url'),
-                 ('description', 'username', 'password')),
+                 ('api_url', 'description', 'username', 'password')),
         'pivotaltracker': (('token', ), tuple()),
         'pushover': (('api_key', 'user_key', 'priority'), ('device', 'sound')),
         'redmine': (('new_issue_url', 'project_url', 'issues_url'),
@@ -1882,14 +1894,16 @@ class Project(GitlabObject):
                            'snippets_enabled', 'container_registry_enabled',
                            'public', 'visibility_level', 'namespace_id',
                            'description', 'path', 'import_url',
-                           'builds_enabled', 'public_builds']
+                           'builds_enabled', 'public_builds',
+                           'only_allow_merge_if_build_succeeds']
     optionalUpdateAttrs = ['name', 'default_branch', 'issues_enabled',
                            'wall_enabled', 'merge_requests_enabled',
                            'wiki_enabled', 'snippets_enabled',
                            'container_registry_enabled', 'public',
                            'visibility_level', 'namespace_id', 'description',
                            'path', 'import_url', 'builds_enabled',
-                           'public_builds']
+                           'public_builds',
+                           'only_allow_merge_if_build_succeeds']
     shortPrintAttr = 'path'
     managers = [
         ('accessrequests', ProjectAccessRequestManager,
@@ -2304,7 +2318,7 @@ class UserProject(GitlabObject):
                            'merge_requests_enabled', 'wiki_enabled',
                            'snippets_enabled', 'public', 'visibility_level',
                            'description', 'builds_enabled', 'public_builds',
-                           'import_url']
+                           'import_url', 'only_allow_merge_if_build_succeeds']
 
 
 class ProjectManager(BaseManager):
